// File: FW_DraaiBank.ino
// ReadOut of 2 axis for a Lathe
// For 2.8 inch TFT-Touch display on an Arduino Nano
// 2015 jan@breem.nl

#include <SPI.h>
#include <SeeedTouchScreen.h> 
#include "TFTv2.h"
#include "LibTFT2p8.h"
#include "controls.h"
#include "HbmRuler.h"

long ZeroX, ZeroZ;
bool Xradius;  // display either Radius or Diameter for the X axis

//******************************************************************************************************
void Display(long Value, int Y, int Color)
{
  char str[10], part[4]; 
  sprintf(str, "%+06ld\n", (Value));
  // we display the whole number and the decimals separately
  // so the decimal point can take less space
  memcpy(&part[0], &str[0], 4); // whole mm's
  part[4] = char(0); // end of string character
  tft_DrawString (part, 69, Y, 5, Color, BLACK);
  memcpy(&part[0], &str[4], 2); // hundredst mm
  part[2] = char(0);
  tft_DrawString (part, 238, Y, 5, Color, BLACK);
  tft_DrawThickHorizontalLine (230, Y + 10, 6, 6, Color); // deciaml point
}  

//******************************************************************************************************
void TouchZeroX(void)
{
  ZeroX = RulerX;
  BeepTime = 200;
}

//******************************************************************************************************
void TouchZeroZ(void)
{
 ZeroZ = RulerZ;
 BeepTime = 200;
}

//******************************************************************************************************
void TouchRD(void)
{
 Xradius = !Xradius;
 DrawButtRD(2, 170, CYAN, Xradius, TouchRD, false);
 BeepTime = 200;
}

//******************************************************************************************************
void setup()
{
  init_HbmRuler();
  tft_init_LibTFT2p8();
  DrawButtRD(2, 170, CYAN, Xradius, TouchRD, true);
  DrawButtZ(2, 90, CYAN, 0, false);
  tft_StoreTouchArea (66, 180, 319, 220, TouchZeroX);
  tft_StoreTouchArea (66, 100, 319, 140, TouchZeroZ);
  // default display the diameter
  Xradius = false; // set to true if you want default the radius displayed
}

//******************************************************************************************************
void loop()
{
  float dRulerX, dRulerZ;
  bool TouchFound;
  
  TouchFound = (tft_DetectTouch() >= 0); // this calls the callback function
  // calculate zero and calibrations in floating point
  dRulerX = (RulerX - ZeroX) * RulerXScale;
  if (!Xradius) dRulerX *= 2.0; // display diameter
  dRulerZ = (RulerZ - ZeroZ) * RulerZScale;
  if (Xradius) Display (long(dRulerX), 180, CYAN); 
      else Display (long(dRulerX), 180, GREEN);
  Display (long(dRulerZ), 100, GREEN);
  if (TouchFound) delay(400); // prevent fast toggling 
}

